@@ -33,8 +33,12 @@ class Feed2Twitter(object):
         self.items = items
         self.username = username
         self.passwd = passwd
+        from pkg_resources import resource_string
+        self.version = resource_string(__name__, '../VERSION')
         self.twApi = twitter.Api(username=self.username, password=self.passwd)
-        self.twApi.SetSource('feed2twitter')
+        self.twApi.SetXTwitterHeaders('feed2twitter', 'http://www. assembla.com/spaces/feed2twitter', self.version)
+#        self.twApi.parameters['source'] = 'feed2twitter'
+#        self.twApi._request_headers['source'] = 'feed2twitter'
         self.set_attr_headers()
         self.rss = readrss.parse(url)
     
@@ -81,6 +85,32 @@ class Feed2Twitter(object):
                 lista = [item for item in self.rss.feed['items'] if item['updated_parsed'] > lastread]
             self.twitIt(reversed(lista[:self.items]))
 
+def PostUpdate(self, text):
+    from twitter import Status
+    from twitter import TwitterError
+    import simplejson
+    '''Post a twitter status message from the authenticated user.
+
+    The twitter.Api instance must be authenticated.
+
+    Args:
+    text: The message text to be posted.  Must be less than 140 characters.
+
+    Returns:
+    A twitter.Status instance representing the message posted
+    '''
+    if not self._username:
+        raise TwitterError("The twitter.Api instance must be authenticated.")
+    if len(text) > 140:
+        raise TwitterError("Text must be less than or equal to 140 characters.")
+    url = 'http://twitter.com/statuses/update.json'
+    data = {'status': text,'source':'feed2twitter'}
+    json = self._FetchUrl(url, post_data=data)
+    data = simplejson.loads(json)
+    return Status.NewFromJsonDict(data)
+
+#setattr(twitter.Api, PostUpdate.__name__, PostUpdate)
+
 def update():
     opt = Options()
     options = opt.parse()
@@ -114,5 +144,10 @@ def update():
     print(interval)
     while True:
         feed2tw = Feed2Twitter(url, username, password, mode, items)
+        from distutils import version
+        if version.LooseVersion(twitter.__version__) > version.LooseVersion('0.5'):
+            feed2tw.twApi.SetSource('feed2twitter')
+        else:
+            setattr(twitter.Api, PostUpdate.__name__, PostUpdate)
         feed2tw.update()
         time.sleep(interval)
